# nso-api
Aims to be an *updated* library to support communicating with Nintendo's Switch Online Service.

## Example:
See example.py for a quick example of how to setup a session token, request game service tokens, and retrieve basic data from Nintendo.

## Installation
Easiest way to install this is to use git to clone a copy

`git clone https://github.com/Jetsurf/nso-api.git`

The install with pip3

`pip3 install .` (from cloned directory)

## Credit
[S2S](https://github.com/frozenpandaman/splatnet2statink) - [@frozenpandaman](https://twitter.com/frozenpandaman) - Original foundation of login flow (iksm.py)

[iMink](https://github.com/JoneWang/imink) - [@jonewang](https://twitter.com/JoneWang) - Built-in F-Token provider

## TODO
- [X] Splatoon 2 API Endpoints
  - Note: Splatfest endpoints are not present. Likely not to be implemented soon due to SplatFests for S2 being done
- [X] Animal Crossing New Horizons API Passport Endpoints
- [X] Login support through iMink
- [X] ACNH "Extras" (ingame/chat support)
- [X] Splatoon 3 API Endpoints

Under construction, keep checking if interested!
